@@ -19,17 +19,11 @@ def load_samples(sample_file_paths):
 
 
 def setup_argparse():
-    parser = argparse.ArgumentParser(
-        description="Read in and analyze samples from plain text file"
-    )
+    parser = argparse.ArgumentParser(description="Read in and analyze samples from plain text file")
 
-    parser.add_argument(
-        "sample_file_paths", help="paths to sample files", default="", nargs="+"
-    )
+    parser.add_argument("sample_file_paths", help="paths to sample files", default="", nargs="+")
 
-    parser.add_argument(
-        "--results", help="Name of output json file", default="samples.json"
-    )
+    parser.add_argument("--results", help="Name of output json file", default="samples.json")
 
     return parser
 
