@@ -43,9 +43,7 @@ def single_task_times():
     for k, v in logmap.items():
         task_durations = []
         try:
-            pre_lines = subprocess.check_output(
-                f'grep " succeeded in " {v}', shell=True
-            ).decode("ascii")
+            pre_lines = subprocess.check_output(f'grep " succeeded in " {v}', shell=True).decode("ascii")
 
             pre_list = pre_lines.strip().split("\n")
 
@@ -65,9 +63,7 @@ def single_task_times():
 def merlin_run_time():
     total = 0
     for err in args.errfile:
-        pre_line = subprocess.check_output(f'grep "real" {err}', shell=True).decode(
-            "ascii"
-        )
+        pre_line = subprocess.check_output(f'grep "real" {err}', shell=True).decode("ascii")
         pre_line = pre_line.strip()
         matches = re.search(r"\d\.\d\d\d", pre_line)
         match = matches[0]
@@ -77,18 +73,14 @@ def merlin_run_time():
         print(f"c{filled_c} merlin run : " + str(result))
     except BaseException:
         result = None
-        print(
-            f"c{filled_c} merlin run : ERROR -- result={result}, args.errfile={args.errfile}"
-        )
+        print(f"c{filled_c} merlin run : ERROR -- result={result}, args.errfile={args.errfile}")
 
 
 def start_verify_time():
     for k, v in logmap.items():
         all_timestamps = []
         try:
-            pre_line = subprocess.check_output(
-                f'grep -m2 "verify" {v} | tail -n1', shell=True
-            ).decode("ascii")
+            pre_line = subprocess.check_output(f'grep -m2 "verify" {v} | tail -n1', shell=True).decode("ascii")
             pre_line = pre_line.strip()
             matches = re.search(r"\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d,\d\d\d", pre_line)
             match = matches[0]
@@ -108,9 +100,7 @@ def start_run_workers_time():
     for k, v in logmap.items():
         all_timestamps = []
         try:
-            pre_line = subprocess.check_output(f'grep -m1 "" {v}', shell=True).decode(
-                "ascii"
-            )
+            pre_line = subprocess.check_output(f'grep -m1 "" {v}', shell=True).decode("ascii")
             pre_line = pre_line.strip()
             matches = re.search(r"\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d,\d\d\d", pre_line)
             match = matches[0]
@@ -127,9 +117,7 @@ def start_sample1_time():
     for k, v in logmap.items():
         all_timestamps = []
         try:
-            pre_line = subprocess.check_output(
-                f"grep -m1 \"Executing step 'null_step'\" {v}", shell=True
-            ).decode("ascii")
+            pre_line = subprocess.check_output(f"grep -m1 \"Executing step 'null_step'\" {v}", shell=True).decode("ascii")
             pre_line = pre_line.strip()
             matches = re.search(r"\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d,\d\d\d", pre_line)
             match = matches[0]
